@@ -22,7 +22,7 @@ package MongoDB;
 # ABSTRACT: Official MongoDB Driver for Perl
 
 use version;
-our $VERSION = 'v0.999.999.1'; # TRIAL
+our $VERSION = 'v0.999.999.2'; # TRIAL
 
 # regexp_pattern was unavailable before 5.10, had to be exported to load the
 # function implementation on 5.10, and was automatically available in 5.10.1
@@ -103,60 +103,21 @@ MongoDB - Official MongoDB Driver for Perl
 
 =head1 VERSION
 
-version v0.999.999.1
+version v0.999.999.2
 
-This is the Beta 1 release for v1.0.0.0.
+This is the Beta 2 release for v1.0.0.
 
 =head1 BETA RELEASE NOTICE AND ROADMAP
 
-The v0.999.999.x releases are B<beta> releases towards v1.0.0.0.  While they
+The v0.999.999.x releases are B<beta> releases towards v1.0.0.  While they
 are believed be as reliable as the stable release series, there will continue
-to be minor optimizations and bug fixes prior to the stable v1.0.0.0.
+to be minor optimizations and bug fixes prior to the stable v1.0.0.
 
 At this point, we believe the API has stabilized, but reserve the right to
 make minor changes.
 
 Using the v0.999.999.x series means that you understand that your code may break
-due to changes in the driver between now and the v1.0.0.0 stable release.
-
-This Beta 1 release includes these major changes since the last Alpha:
-
-=over
-
-=item *
-
-Added new L<MongoDB::IndexView> API for manipulating indexes.  Like the new
-CRUD API, this will be standard across MongoDB drivers.  Old legacy index
-helper methods were deprecated.
-
-=item *
-
-Finished overhauling MongoDB::MongoClient configuration.  Everything
-is immutable and globals are removed.  Connection string options have
-been revised to match MongoClient options and connection string options
-always take precedence.
-
-=item *
-
-Updated the Bulk API to use the new CRUD API method names and deprecated
-the old method names.
-
-=item *
-
-Added support for serializing/deserializing Time::Moment objects.
-
-=item *
-
-Added 'save_one' method for idempotent replace-or-upsert and deprecated
-the legacy 'save' method.
-
-=item *
-
-Integers that fit in 32-bits are now encoded as BSON Int32; larger integers
-are encodeed as BSON Int64; Math::BigInt objects are always encoded as BSON
-Int64.
-
-=back
+due to changes in the driver between now and the v1.0.0 stable release.
 
 More details on changes and how to upgrade applications may be found in
 L<MongoDB::Upgrading>.
@@ -164,42 +125,23 @@ L<MongoDB::Upgrading>.
 =head2 Roadmap
 
 The next Beta release is expected around the end of June 2015.
-The v1.0.0.0 release is expected around the end of July 2015.
+The stable v1.0.0 release is expected around the end of July 2015.
 
-Some expected (but not guaranteed) changes in future releases include:
+Some expected changes in future releases include:
 
 =over
 
 =item *
 
+Bug fixes, as necesary.
+
+=item *
+
 Profiling and optimization of common operations.
 
 =item *
 
-Documentation will continue to be revised.
-
-=back
-
-In order to avoid holding up v1.0.0.0, the following changes will be
-B<deferred> until after the v1.0.0.0 release:
-
-=over
-
-=item *
-
-The driver will switch OO frameworks from Moose to Moo.  This will
-significantly reduce the size of the total dependency tree and paves the way
-for a pure-Perl version of the driver.
-
-=item *
-
-BSON encoding will be extracted to a separate distribution, with both pure-Perl
-and C variants available.
-
-=item *
-
-Transformation of Perl data structures to/from BSON will become more
-customizable.
+Documentation revisions.
 
 =back
 
@@ -311,43 +253,28 @@ read_documents
 
 =head1 SEMANTIC VERSIONING SCHEME
 
-Starting with MongoDB v0.704.0.0, the driver will be using a modified
-L<semantic versioning|http://semver.org/> scheme.
-
-Versions will have a C<vX.Y.Z.N> tuple scheme with the following properties:
+Starting with MongoDB C<v1.0.0>, the driver reverts to the more-familiar
+three-part, version-tuple numbering scheme used by both Perl and MongoDB:
+C<vX.Y.Z>
 
 =over 4
 
 =item *
 
-C<X> will be incremented for incompatible API changes
+C<X> will be incremented for incompatible API changes.
 
 =item *
 
-C<Y> will be incremented for new functionality that is backwards compatible
+Even-value increments of C<Y> indicate stable releases with new functionality.  C<Z> will be incremented for bug fixes.
 
 =item *
 
-C<Z> will be incremented for backwards-compatible bug fixes
-
-=item *
-
-C<N> will be zero for a stable release; C<N> will be non-zero for development releases
+Odd-value increments of C<Y> indicate unstable ("development") releases that should not be used in production.  C<Z> increments have no semantic meaning; they indicate only successive development releases.
 
 =back
 
-We use C<N> because CPAN does not support pre-release version labels (e.g.
-"-alpha1") and requires non-decreasing version numbers for releases.
-
-When C<N> is non-zero, C<X>, C<Y>, and C<Z> have no semantic meaning except to
-indicate the last stable release.
-
-For example, v0.704.0.1 is merely the first development release after
-v0.704.0.0.  The next stable release could be a bug fix (v0.704.1.0), a feature
-enhancement (v0.705.0.0), or an API change (v1.0.0.0).
-
-See the Changes file included with development releases for an indication of
-the nature of changes involved.
+See the Changes file included with releases for an indication of the nature of
+changes involved.
 
 =for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
