@@ -19,7 +19,7 @@ package MongoDB::MongoClient;
 # ABSTRACT: A connection to a MongoDB server or multi-server deployment
 
 use version;
-our $VERSION = 'v0.999.999.1'; # TRIAL
+our $VERSION = 'v0.999.999.2'; # TRIAL
 
 use Moose;
 use MongoDB;
@@ -211,9 +211,15 @@ sub _build_bson_codec {
 #pod
 #pod The default is 20,000 ms.
 #pod
-#pod This may be set in a connection string with the C<connectTimeoutMS> option.
+#pod If set to a negative value, connection operations will block indefinitely
+#pod until the server replies or until the operating system TCP/IP stack gives
+#pod up (e.g. if the name can't resolve or there is no process listening on the
+#pod target host/port).
 #pod
-#pod XXX what about 0? negative?
+#pod A zero value polls the socket during connection and is thus likely to fail
+#pod except when talking to a local process (and perhaps even then).
+#pod
+#pod This may be set in a connection string with the C<connectTimeoutMS> option.
 #pod
 #pod =cut
 
@@ -297,8 +303,8 @@ sub _build_db_name {
 
 #pod =attr heartbeat_frequency_ms
 #pod
-#pod The time in milliseconds between scans of all servers to check if they
-#pod are up and update their latency.  Defaults to 60,000 ms.
+#pod The time in milliseconds (non-negative) between scans of all servers to
+#pod check if they are up and update their latency.  Defaults to 60,000 ms.
 #pod
 #pod This may be set in a connection string with the C<heartbeatFrequencyMS> option.
 #pod
@@ -306,7 +312,7 @@ sub _build_db_name {
 
 has heartbeat_frequency_ms => (
     is      => 'ro',
-    isa     => Num,
+    isa     => NonNegNum,
     lazy    => 1,
     builder => '_build_heartbeat_frequency_ms',
 );
@@ -351,9 +357,9 @@ sub _build_j {
 #pod =attr local_threshold_ms
 #pod
 #pod The width of the 'latency window': when choosing between multiple suitable
-#pod servers for an operation, the acceptable delta in milliseconds between shortest
-#pod and longest average round-trip times.  Servers within the latency window are
-#pod selected randomly.
+#pod servers for an operation, the acceptable delta in milliseconds
+#pod (non-negative) between shortest and longest average round-trip times.
+#pod Servers within the latency window are selected randomly.
 #pod
 #pod Set this to "0" to always select the server with the shortest average round
 #pod trip time.  Set this to a very high value to always randomly choose any known
@@ -369,7 +375,7 @@ sub _build_j {
 
 has local_threshold_ms => (
     is      => 'ro',
-    isa     => Num,
+    isa     => NonNegNum,
     lazy    => 1,
     builder => '_build_local_threshold_ms',
 );
@@ -385,15 +391,18 @@ sub _build_local_threshold_ms {
 
 #pod =attr max_time_ms
 #pod
-#pod Specifies the maximum amount of time in milliseconds that the server should use
-#pod for working on a query.  Defaults to 29,500, slightly shorter than the
-#pod L</socket_timeout_ms>, as getting a definitive (albeit negative) response from
-#pod the server is preferred over a getting a socket timeout.
+#pod Specifies the maximum amount of time in (non-negative) milliseconds that the
+#pod server should use for working on a query.  Defaults to 29,500, slightly shorter
+#pod than the L</socket_timeout_ms>, as getting a definitive (albeit negative)
+#pod response from the server is preferred over a getting a socket timeout.
+#pod
+#pod Make sure this value is shorter than C<socket_timeout_ms>.
 #pod
 #pod B<Note>: this will only be used for server versions 2.6 or greater, as that
 #pod was when the C<$maxTimeMS> meta-operator was introduced.
 #pod
-#pod XXX ensure this is shorter than C<socket_timeout_ms>?
+#pod B<Also Note>: Unlike other timeout values, when this is set to zero,
+#pod C<$maxTimeMS> is disabled, not an immediate timeout.
 #pod
 #pod This may be set in a connection string with the C<maxTimeMS> option.
 #pod
@@ -596,7 +605,7 @@ sub _build_server_selection_timeout_ms {
 #pod
 #pod If a socket to a server has not been used in this many milliseconds, an
 #pod C<ismaster> command will be issued to check the status of the server before
-#pod issuing any reads or writes.
+#pod issuing any reads or writes. Must be non-negative.
 #pod
 #pod The default is 5,000 ms.
 #pod
@@ -607,7 +616,7 @@ sub _build_server_selection_timeout_ms {
 
 has socket_check_interval_ms => (
     is      => 'ro',
-    isa     => Num,
+    isa     => NonNegNum,
     lazy    => 1,
     builder => '_build_socket_check_interval_ms',
 );
@@ -628,7 +637,12 @@ sub _build_socket_check_interval_ms {
 #pod
 #pod The default is 30,000 ms.
 #pod
-#pod XXX what about 0? negative?
+#pod If set to a negative value, socket operations will block indefinitely
+#pod until the server replies or until the operating system TCP/IP stack
+#pod gives up.
+#pod
+#pod A zero value polls the socket for available data and is thus likely to fail
+#pod except when talking to a local process (and perhaps even then).
 #pod
 #pod This may be set in a connection string with the C<socketTimeoutMS> option.
 #pod
@@ -1018,8 +1032,8 @@ sub _build__topology {
         min_wire_version            => MIN_WIRE_VERSION,
         credential                  => $self->_credential,
         link_options                => {
-            connect_timeout => $self->connect_timeout_ms / 1000,
-            socket_timeout => $self->socket_timeout_ms / 1000,
+            connect_timeout => $self->connect_timeout_ms >= 0 ? $self->connect_timeout_ms / 1000 : -1,
+            socket_timeout  => $self->socket_timeout_ms  >= 0 ? $self->socket_timeout_ms  / 1000 : -1,
             with_ssl   => !!$self->ssl,
             ( ref( $self->ssl ) eq 'HASH' ? ( SSL_options => $self->ssl ) : () ),
         },
@@ -1468,7 +1482,7 @@ MongoDB::MongoClient - A connection to a MongoDB server or multi-server deployme
 
 =head1 VERSION
 
-version v0.999.999.1
+version v0.999.999.2
 
 =head1 SYNOPSIS
 
@@ -1596,9 +1610,15 @@ new connection to a server.
 
 The default is 20,000 ms.
 
-This may be set in a connection string with the C<connectTimeoutMS> option.
+If set to a negative value, connection operations will block indefinitely
+until the server replies or until the operating system TCP/IP stack gives
+up (e.g. if the name can't resolve or there is no process listening on the
+target host/port).
 
-XXX what about 0? negative?
+A zero value polls the socket during connection and is thus likely to fail
+except when talking to a local process (and perhaps even then).
+
+This may be set in a connection string with the C<connectTimeoutMS> option.
 
 =head2 connect_type
 
@@ -1640,8 +1660,8 @@ for illustration):
 
 =head2 heartbeat_frequency_ms
 
-The time in milliseconds between scans of all servers to check if they
-are up and update their latency.  Defaults to 60,000 ms.
+The time in milliseconds (non-negative) between scans of all servers to
+check if they are up and update their latency.  Defaults to 60,000 ms.
 
 This may be set in a connection string with the C<heartbeatFrequencyMS> option.
 
@@ -1658,9 +1678,9 @@ strings 'true' or 'false'.
 =head2 local_threshold_ms
 
 The width of the 'latency window': when choosing between multiple suitable
-servers for an operation, the acceptable delta in milliseconds between shortest
-and longest average round-trip times.  Servers within the latency window are
-selected randomly.
+servers for an operation, the acceptable delta in milliseconds
+(non-negative) between shortest and longest average round-trip times.
+Servers within the latency window are selected randomly.
 
 Set this to "0" to always select the server with the shortest average round
 trip time.  Set this to a very high value to always randomly choose any known
@@ -1674,15 +1694,18 @@ This may be set in a connection string with the C<localThresholdMS> option.
 
 =head2 max_time_ms
 
-Specifies the maximum amount of time in milliseconds that the server should use
-for working on a query.  Defaults to 29,500, slightly shorter than the
-L</socket_timeout_ms>, as getting a definitive (albeit negative) response from
-the server is preferred over a getting a socket timeout.
+Specifies the maximum amount of time in (non-negative) milliseconds that the
+server should use for working on a query.  Defaults to 29,500, slightly shorter
+than the L</socket_timeout_ms>, as getting a definitive (albeit negative)
+response from the server is preferred over a getting a socket timeout.
+
+Make sure this value is shorter than C<socket_timeout_ms>.
 
 B<Note>: this will only be used for server versions 2.6 or greater, as that
 was when the C<$maxTimeMS> meta-operator was introduced.
 
-XXX ensure this is shorter than C<socket_timeout_ms>?
+B<Also Note>: Unlike other timeout values, when this is set to zero,
+C<$maxTimeMS> is disabled, not an immediate timeout.
 
 This may be set in a connection string with the C<maxTimeMS> option.
 
@@ -1785,7 +1808,7 @@ option.
 
 If a socket to a server has not been used in this many milliseconds, an
 C<ismaster> command will be issued to check the status of the server before
-issuing any reads or writes.
+issuing any reads or writes. Must be non-negative.
 
 The default is 5,000 ms.
 
@@ -1799,7 +1822,12 @@ reply from the server before issuing a network exception.
 
 The default is 30,000 ms.
 
-XXX what about 0? negative?
+If set to a negative value, socket operations will block indefinitely
+until the server replies or until the operating system TCP/IP stack
+gives up.
+
+A zero value polls the socket for available data and is thus likely to fail
+except when talking to a local process (and perhaps even then).
 
 This may be set in a connection string with the C<socketTimeoutMS> option.
 
