@@ -25,16 +25,18 @@ use warnings;
 package MongoDB::_Link;
 
 use version;
-our $VERSION = 'v0.999.999.1'; # TRIAL
+our $VERSION = 'v0.999.999.2'; # TRIAL
 
 use Config;
 use Errno qw[EINTR EPIPE];
 use IO::Socket qw[SOCK_STREAM];
 use Scalar::Util qw/refaddr/;
-use Time::HiRes qw/gettimeofday tv_interval/;
+use Socket qw/SOL_SOCKET SO_KEEPALIVE IPPROTO_TCP TCP_NODELAY/;
+use Time::HiRes qw/time gettimeofday tv_interval/;
 use MongoDB::Error;
 
 use constant {
+    HAS_GETTIME          => Time::HiRes::d_clock_gettime(),
     HAS_THREADS          => $Config{usethreads},
     P_INT32              => $] lt '5.010' ? 'l' : 'l<',
     MAX_BSON_OBJECT_SIZE => 4_194_304,
@@ -88,12 +90,18 @@ sub connect {
         $self->{local_address} ? ( LocalAddr => $self->{local_address} ) : (),
         Proto   => 'tcp',
         Type    => SOCK_STREAM,
-        Timeout => $self->{connect_timeout},
+        Timeout => $self->{connect_timeout} >= 0 ? $self->{connect_timeout} : undef,
     ) or MongoDB::NetworkError->throw(qq/Could not connect to '$host:$port': $@\n/);
 
     binmode( $self->{fh} )
       or MongoDB::InternalError->throw(qq/Could not binmode() socket: '$!'\n/);
 
+    defined( $self->{fh}->setsockopt(IPPROTO_TCP, TCP_NODELAY, 1) )
+      or MongoDB::InternalError->throw(qq/Could not set TCP_NODELAY on socket: '$!'\n/);
+
+    defined( $self->{fh}->setsockopt(SOL_SOCKET, SO_KEEPALIVE, 1) )
+      or MongoDB::InternalError->throw(qq/Could not set SO_KEEPALIVE on socket: '$!'\n/);
+
     $self->start_ssl($host) if $self->{with_ssl};
 
     $self->{pid}       = $$;
@@ -306,14 +314,14 @@ sub _read_bytes {
 sub _do_timeout {
     my ( $self, $type, $timeout ) = @_;
     $timeout = $self->{socket_timeout}
-      unless defined $timeout && $timeout >= 0;
+      unless defined $timeout;
 
     my $fd = fileno $self->{fh};
     defined $fd && $fd >= 0
       or MongoDB::InternalError->throw(qq/select(2): 'Bad file descriptor'\n/);
 
-    my $initial = time;
-    my $pending = $timeout;
+    my $initial = HAS_GETTIME ? Time::HiRes::clock_gettime(Time::HiRes::CLOCK_MONOTONIC()) : time;
+    my $pending = $timeout >= 0 ? $timeout : undef;
     my $nfound;
 
     vec( my $fdset = '', $fd, 1 ) = 1;
@@ -326,7 +334,9 @@ sub _do_timeout {
         if ( $nfound == -1 ) {
             $! == EINTR
               or MongoDB::NetworkError->throw(qq/select(2): '$!'\n/);
-            redo if !defined($timeout) || ( $pending = $timeout - ( time - $initial ) ) > 0;
+            redo if !defined($pending);
+            my $now = HAS_GETTIME ? Time::HiRes::clock_gettime(Time::HiRes::CLOCK_MONOTONIC()) : time;
+            redo if ( $pending = $timeout - ( $now - $initial ) ) > 0;
             $nfound = 0;
         }
         last;
